# mypy-boto3-groundstation

[![PyPI - mypy-boto3-groundstation](https://img.shields.io/pypi/v/mypy-boto3-groundstation.svg?color=blue)](https://pypi.org/project/mypy-boto3-groundstation)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-groundstation.svg?color=blue)](https://pypi.org/project/mypy-boto3-groundstation)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.GroundStation 1.15.4](https://boto3.amazonaws.com/v1/documentation/api/1.15.4/reference/services/groundstation.html#GroundStation) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-groundstation](#mypy-boto3-groundstation)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `GroundStation` service.

```bash
python -m pip install boto3-stubs[groundstation]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[groundstation]` in your environment: `python -m pip install 'boto3-stubs[groundstation]'`

Both type checking and auto-complete should work for `GroundStation` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[groundstation]` in your environment: `python -m pip install 'boto3-stubs[groundstation]'`

Both type checking and auto-complete should work for `GroundStation` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[groundstation]` in your environment: `python -m pip install 'boto3-stubs[groundstation]'`
- Run `mypy` as usual

Type checking should work for `GroundStation` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[groundstation]` in your environment: `python -m pip install 'boto3-stubs[groundstation]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `GroundStation` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`GroundStationClient` provides annotations for `boto3.client("groundstation")`.

```python
import boto3

from mypy_boto3_groundstation import GroundStationClient

client: GroundStationClient = boto3.client("groundstation")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GroundStationClient = session.client("groundstation")
```

### Paginators annotations

`mypy_boto3_groundstation.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_groundstation import GroundStationClient
from mypy_boto3_groundstation.paginator import (
    ListConfigsPaginator,
    ListContactsPaginator,
    ListDataflowEndpointGroupsPaginator,
    ListGroundStationsPaginator,
    ListMissionProfilesPaginator,
    ListSatellitesPaginator,
)

client: GroundStationClient = boto3.client("groundstation")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_configs_paginator: ListConfigsPaginator = client.get_paginator("list_configs")
list_contacts_paginator: ListContactsPaginator = client.get_paginator("list_contacts")
list_dataflow_endpoint_groups_paginator: ListDataflowEndpointGroupsPaginator = client.get_paginator("list_dataflow_endpoint_groups")
list_ground_stations_paginator: ListGroundStationsPaginator = client.get_paginator("list_ground_stations")
list_mission_profiles_paginator: ListMissionProfilesPaginator = client.get_paginator("list_mission_profiles")
list_satellites_paginator: ListSatellitesPaginator = client.get_paginator("list_satellites")
```







### Typed dictionations

`mypy_boto3_groundstation.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_groundstation.type_defs import (
    AntennaDemodDecodeDetailsTypeDef,
    AntennaDownlinkConfigTypeDef,
    AntennaDownlinkDemodDecodeConfigTypeDef,
    AntennaUplinkConfigTypeDef,
    ConfigDetailsTypeDef,
    ConfigIdResponseTypeDef,
    ConfigListItemTypeDef,
    ConfigTypeDataTypeDef,
    ContactDataTypeDef,
    ContactIdResponseTypeDef,
    DataflowDetailTypeDef,
    DataflowEndpointConfigTypeDef,
    DataflowEndpointGroupIdResponseTypeDef,
    DataflowEndpointListItemTypeDef,
    DataflowEndpointTypeDef,
    DecodeConfigTypeDef,
    DemodulationConfigTypeDef,
    DescribeContactResponseTypeDef,
    DestinationTypeDef,
    EirpTypeDef,
    ElevationTypeDef,
    EndpointDetailsTypeDef,
    FrequencyBandwidthTypeDef,
    FrequencyTypeDef,
    GetConfigResponseTypeDef,
    GetDataflowEndpointGroupResponseTypeDef,
    GetMinuteUsageResponseTypeDef,
    GetMissionProfileResponseTypeDef,
    GetSatelliteResponseTypeDef,
    GroundStationDataTypeDef,
    ListConfigsResponseTypeDef,
    ListContactsResponseTypeDef,
    ListDataflowEndpointGroupsResponseTypeDef,
    ListGroundStationsResponseTypeDef,
    ListMissionProfilesResponseTypeDef,
    ListSatellitesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    MissionProfileIdResponseTypeDef,
    MissionProfileListItemTypeDef,
    PaginatorConfigTypeDef,
    SatelliteListItemTypeDef,
    SecurityDetailsTypeDef,
    SocketAddressTypeDef,
    SourceTypeDef,
    SpectrumConfigTypeDef,
    TrackingConfigTypeDef,
    UplinkEchoConfigTypeDef,
    UplinkSpectrumConfigTypeDef,
)

def get_structure() -> AntennaDemodDecodeDetailsTypeDef:
    return {
      ...
    }
```
